| Title: | An R Package For Geneset Enrichment Workflows |
|---|---|
| Description: | An R Package for Geneset Enrichment Workflows. |
| Authors: | Anthony Federico [aut], Andrew Chen [aut, cre], Stefano Monti [aut] |
| Maintainer: | Andrew Chen <[email protected]> |
| License: | GPL-3 + file LICENSE |
| Version: | 2.11.0 |
| Built: | 2026-05-10 09:34:51 UTC |
| Source: | https://github.com/bioc/hypeR |
Clean labels of genesets
clean_genesets(x)clean_genesets(x)
x |
A vector of labels |
HALLMARK <- msigdb_download("Homo sapiens", "H") names(HALLMARK) <- clean_genesets(names(HALLMARK)) head(names(HALLMARK))HALLMARK <- msigdb_download("Homo sapiens", "H") names(HALLMARK) <- clean_genesets(names(HALLMARK)) head(names(HALLMARK))
Get enrichr available genesets
enrichr_available( db = c("Enrichr", "YeastEnrichr", "FlyEnrichr", "WormEnrichr", "FishEnrichr") )enrichr_available( db = c("Enrichr", "YeastEnrichr", "FlyEnrichr", "WormEnrichr", "FishEnrichr") )
db |
A species |
A dataframe of available genesets
enrichr_available()enrichr_available()
Download data from enrichr in the form of a named list
enrichr_download( genesets, db = c("Enrichr", "YeastEnrichr", "FlyEnrichr", "WormEnrichr", "FishEnrichr") )enrichr_download( genesets, db = c("Enrichr", "YeastEnrichr", "FlyEnrichr", "WormEnrichr", "FishEnrichr") )
genesets |
A name corresponding to available genesets |
db |
A species |
A list of genesets
ATLAS <- enrichr_download("Human_Gene_Atlas")ATLAS <- enrichr_download("Human_Gene_Atlas")
Download data from enrichr in the form of a gsets object
enrichr_gsets( genesets, db = c("Enrichr", "YeastEnrichr", "FlyEnrichr", "WormEnrichr", "FishEnrichr"), clean = FALSE )enrichr_gsets( genesets, db = c("Enrichr", "YeastEnrichr", "FlyEnrichr", "WormEnrichr", "FishEnrichr"), clean = FALSE )
genesets |
A name corresponding to available genesets |
db |
A species |
clean |
Use true to clean labels of genesets |
A gsets object
ATLAS <- enrichr_gsets("Human_Gene_Atlas")ATLAS <- enrichr_gsets("Human_Gene_Atlas")
Shiny server module for geneset selection
genesets_Server(id, clean = FALSE)genesets_Server(id, clean = FALSE)
id |
A unique namespace identifier matching to interface |
clean |
Use true to clean geneset names |
Shiny server code
Shiny interface module for geneset selection
genesets_UI(id)genesets_UI(id)
id |
A unique namespace identifier |
Shiny ui elements
Enrichment plot implemented in ggplot
ggeplot(n, positions, x_axis, y_axis, title = "")ggeplot(n, positions, x_axis, y_axis, title = "")
n |
The length of a ranked list |
positions |
A vector of positions in the ranked list |
x_axis |
The x-axis of a running enrichment score |
y_axis |
The y-axis of a running enrichment score |
title |
Plot title |
A ggplot object
Venn diagram implemented in ggplot
ggvenn(a, b, ga, gb, title = "")ggvenn(a, b, ga, gb, title = "")
a |
A vector for group a |
b |
A vector for group b |
ga |
A string label for group a |
gb |
A string label for group b |
title |
Plot title |
A ggplot object
A genesets object
A genesets object
rgsets
genesetsA named list of genesets
nameA character vector describing source of genesets
versionA character vector describing versioning
new()
Create a gsets object
gsets$new( genesets, name = "Custom", version = "", clean = FALSE, quiet = FALSE )
genesetsA named list of genesets
nameA character vector describing source of genesets
versionA character vector describing versioning
cleanUse true to clean labels of genesets
quietUse true to silence warnings
A new gsets object
print()
Print genesets information
gsets$print()
NULL
list()
Return genesets as a list
gsets$list()
A list of genesets
info()
Returns versioning information
gsets$info()
A character vector with name and version
reduce()
Reduces genesets to a background distribution of symbols
gsets$reduce(background)
backgroundA character vector of symbols
A gsets object
clone()
The objects of this class are cloneable with this method.
gsets$clone(deep = FALSE)
deepWhether to make a deep clone.
genesets <- list("GSET1" = c("GENE1", "GENE2", "GENE3"), "GSET2" = c("GENE4", "GENE5", "GENE6"), "GSET3" = c("GENE7", "GENE8", "GENE9")) gsets_obj <- gsets$new(genesets, name="example", version="v1.0") print(gsets_obj)genesets <- list("GSET1" = c("GENE1", "GENE2", "GENE3"), "GSET2" = c("GENE4", "GENE5", "GENE6"), "GSET3" = c("GENE7", "GENE8", "GENE9")) gsets_obj <- gsets$new(genesets, name="example", version="v1.0") print(gsets_obj)
A hyp object
A hyp object
multihyp
dataA dataframe returned by hypeR()
plotsA list of plots returned by hypeR()
argsA list of arguments passed to hypeR()
infoExported information for reproducibility
new()
Create a hyp object
hyp$new(data, plots = NULL, args = NULL, info = NULL)
dataA dataframe returned by hypeR()
plotsA list of plots returned by hypeR()
argsA list of arguments passed to hypeR()
infoExported information for reproducibility
A new hyp object
print()
Print hyp obect
hyp$print()
NULL
as.data.frame()
Extract dataframe from hyp obect
hyp$as.data.frame()
NULL
clone()
The objects of this class are cloneable with this method.
hyp$clone(deep = FALSE)
deepWhether to make a deep clone.
data <- data.frame(replicate(5,sample(0:1,10,rep=TRUE))) args <- list("arg_1"=1, "arg_2"=2, "arg_3"=3) hyp_obj <- hyp$new(data, args=args)data <- data.frame(replicate(5,sample(0:1,10,rep=TRUE))) args <- list("arg_1"=1, "arg_2"=2, "arg_3"=3) hyp_obj <- hyp$new(data, args=args)
Visualize hyp/multihyp objects as a dots plot
hyp_dots( hyp_obj, top = 20, abrv = 50, size_by = c("genesets", "significance", "none"), pval = 1, fdr = 1, val = c("fdr", "pval"), title = "", merge = FALSE )hyp_dots( hyp_obj, top = 20, abrv = 50, size_by = c("genesets", "significance", "none"), pval = 1, fdr = 1, val = c("fdr", "pval"), title = "", merge = FALSE )
hyp_obj |
A hyp or multihyp object |
top |
Limit number of genesets shown |
abrv |
Abbreviation length of geneset labels |
size_by |
Size dots by e.g. c("genesets", "significance", "none") |
pval |
Filter results to be less than pval cutoff |
fdr |
Filter results to be less than fdr cutoff |
val |
Choose significance value for plot e.g. c("fdr", "pval") |
title |
Plot title |
merge |
Use true to merge a multihyp object into one plot |
A ggplot object
genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) hyp_dots(hyp_obj, val="fdr")genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) hyp_dots(hyp_obj, val="fdr")
Visualize hyp/multihyp objects as an enrichment map
hyp_emap( hyp_obj, similarity_metric = c("jaccard_similarity", "overlap_similarity"), similarity_cutoff = 0.2, pval = 1, fdr = 1, val = c("fdr", "pval"), top = NULL, title = "" )hyp_emap( hyp_obj, similarity_metric = c("jaccard_similarity", "overlap_similarity"), similarity_cutoff = 0.2, pval = 1, fdr = 1, val = c("fdr", "pval"), top = NULL, title = "" )
hyp_obj |
A hyp or multihyp object |
similarity_metric |
Metric to calculate geneset similarity |
similarity_cutoff |
Geneset similarity cutoff |
pval |
Filter results to be less than pval cutoff |
fdr |
Filter results to be less than fdr cutoff |
val |
Choose significance value shown above nodes e.g. c("fdr", "pval") |
top |
Limit number of pathways shown |
title |
Plot title |
A visNetwork object
genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) hyp_emap(hyp_obj, top=30, val="fdr")genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) hyp_emap(hyp_obj, top=30, val="fdr")
Visualize hyp/multihyp objects as a hiearchy map
hyp_hmap( hyp_obj, pval = 1, fdr = 1, val = c("fdr", "pval"), top = NULL, title = "", graph = FALSE )hyp_hmap( hyp_obj, pval = 1, fdr = 1, val = c("fdr", "pval"), top = NULL, title = "", graph = FALSE )
hyp_obj |
A hyp or multihyp object |
pval |
Filter results to be less than pval cutoff |
fdr |
Filter results to be less than fdr cutoff |
val |
Choose significance value displayed when hovering nodes e.g. c("fdr", "pval") |
top |
Limit number of pathways shown |
title |
Plot title |
graph |
Return an igraph object instead |
A visNetwork object
genesets <- hyperdb_rgsets("REACTOME", "70.0") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) hyp_hmap(hyp_obj, top=60)genesets <- hyperdb_rgsets("REACTOME", "70.0") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) hyp_hmap(hyp_obj, top=60)
Convert a hyp object to a reactable table
hyp_show(hyp_obj, simple = FALSE)hyp_show(hyp_obj, simple = FALSE)
hyp_obj |
A hyp object |
simple |
Use true to only include essential columns |
A reactable table
genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) hyp_show(hyp_obj)genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) hyp_show(hyp_obj)
Export hyp/multihyp object to excel
hyp_to_excel(hyp_obj, file_path, cols = NULL, versioning = TRUE)hyp_to_excel(hyp_obj, file_path, cols = NULL, versioning = TRUE)
hyp_obj |
A hyp or multihyp object |
file_path |
A file path |
cols |
Dataframe columns to include |
versioning |
Add sheet with versioning information |
genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) hyp_to_excel(hyp_obj, file_path="pathways.xlsx")genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) hyp_to_excel(hyp_obj, file_path="pathways.xlsx")
Convert a hyp object to an igraph object
hyp_to_graph(hyp_obj)hyp_to_graph(hyp_obj)
hyp_obj |
A hyp object |
An igraph object
genesets <- hyperdb_rgsets("REACTOME", "70.0") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) ig <- hyp_to_graph(hyp_obj)genesets <- hyperdb_rgsets("REACTOME", "70.0") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) ig <- hyp_to_graph(hyp_obj)
Export hyp object to rmarkdown
hyp_to_rmd( hyp_obj, file_path, title = "Workflow Report", subtitle = "", author = "", header = "Results", versioning = TRUE, show_dots = TRUE, show_emaps = TRUE, show_hmaps = FALSE, show_tables = TRUE, hyp_dots_args = list(top = 15, val = "fdr"), hyp_emap_args = list(top = 25, val = "fdr", similarity_metric = "jaccard_similarity", similarity_cutoff = 0.2), hyp_hmap_args = list(top = 25, val = "fdr"), custom_rmd_config = NULL, custom_pre_content = NULL, custom_post_content = NULL, session_info = FALSE )hyp_to_rmd( hyp_obj, file_path, title = "Workflow Report", subtitle = "", author = "", header = "Results", versioning = TRUE, show_dots = TRUE, show_emaps = TRUE, show_hmaps = FALSE, show_tables = TRUE, hyp_dots_args = list(top = 15, val = "fdr"), hyp_emap_args = list(top = 25, val = "fdr", similarity_metric = "jaccard_similarity", similarity_cutoff = 0.2), hyp_hmap_args = list(top = 25, val = "fdr"), custom_rmd_config = NULL, custom_pre_content = NULL, custom_post_content = NULL, session_info = FALSE )
hyp_obj |
A hyp object, multihyp object, or list of multihyp objects |
file_path |
A file path |
title |
Title of markdown report |
subtitle |
Subtitle of markdown report |
author |
Authors of markdown report |
header |
Header name of tabset section |
versioning |
Add versioning information |
show_dots |
Option to show dots plots in tabs |
show_emaps |
Option to show enrichment maps in tabs |
show_hmaps |
Option to show hiearchy maps in tabs |
show_tables |
Option to show table in tabs |
hyp_dots_args |
A list of keyword arguments passed to hyp_dots |
hyp_emap_args |
A list of keyword arguments passed to hyp_emap |
hyp_hmap_args |
A list of keyword arguments passed to hyp_hmap |
custom_rmd_config |
Replace configuration section of markdown report |
custom_pre_content |
Insert custom content before tabset section |
custom_post_content |
Insert custom content after tabset section |
session_info |
Use true to include session info |
Export hyp/multihyp object to table
hyp_to_table(hyp_obj, file_path, sep = "\t", cols = NULL, versioning = TRUE)hyp_to_table(hyp_obj, file_path, sep = "\t", cols = NULL, versioning = TRUE)
hyp_obj |
A hyp or multihyp object |
file_path |
A file path for hyp objects and directory for multihyp objects |
sep |
The field separator string |
cols |
Dataframe columns to include |
versioning |
Add header with versioning information |
genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) hyp_to_table(hyp_obj, file_path="pathways.txt")genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) hyp_to_table(hyp_obj, file_path="pathways.txt")
Calculate enrichment of one or more signatures
hypeR( signature, genesets, test = c("hypergeometric", "kstest"), background = 23467, power = 1, absolute = FALSE, pval = 1, fdr = 1, plotting = FALSE, quiet = TRUE )hypeR( signature, genesets, test = c("hypergeometric", "kstest"), background = 23467, power = 1, absolute = FALSE, pval = 1, fdr = 1, plotting = FALSE, quiet = TRUE )
signature |
A vector of symbols |
genesets |
A gsets/rgsets object or a named list of genesets |
test |
Choose an enrichment type e.g. c("hypergeometric", "kstest") |
background |
Size or character vector of background population genes |
power |
Exponent for weights (kstest only) |
absolute |
Takes max-min score rather than the max deviation from null (kstest only) |
pval |
Filter results to be less than pval cutoff |
fdr |
Filter results to be less than fdr cutoff |
plotting |
Use true to generate plots for each geneset test (may slow performance) |
quiet |
Use true to suppress logs and warnings |
A hyp object
genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522)genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY") signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522)
Check available data to download from hyperdb
hyperdb_available()hyperdb_available()
hyperdb_available()hyperdb_available()
Download data from hyperdb
hyperdb_gsets(source, gsets)hyperdb_gsets(source, gsets)
source |
A source identifier |
gsets |
A genesets identifier |
A list
KEGG <- hyperdb_gsets("KEGG", "KEGG_v92.0.rds")KEGG <- hyperdb_gsets("KEGG", "KEGG_v92.0.rds")
Download data from hyperdb in the form of a rgsets object
hyperdb_rgsets(rgsets, version)hyperdb_rgsets(rgsets, version)
rgsets |
A name corresponding to an available relational genesets object |
version |
A version number |
An rgsets object
REACTOME <- hyperdb_rgsets("REACTOME", "70.0")REACTOME <- hyperdb_rgsets("REACTOME", "70.0")
A differential expression table
limmalimma
A data frame
Get msigdbr available genesets
msigdb_available(species = "Homo sapiens")msigdb_available(species = "Homo sapiens")
species |
A species to determine gene symbols (refer to ?msigdbr::msigdbr for available species) |
A dataframe of available genesets
msigdb_available("Homo sapiens")msigdb_available("Homo sapiens")
Download data from msigdb in the form of a named list
msigdb_download(species, collection, subcollection = NULL)msigdb_download(species, collection, subcollection = NULL)
species |
A species to determine gene symbols (refer to ?msigdbr::msigdbr for available species) |
collection |
Geneset collection (refer to ?msigdbr::msigdbr_collections for available categories) |
subcollection |
Geneset subcollection (refer to ?msigdbr::msigdbr_collections for available subcategories) |
A list of genesets
HALLMARK_HUMAN <- msigdb_download("Homo sapiens", "H") HALLMARK_MOUSE <- msigdb_download("Mus musculus", "MH")HALLMARK_HUMAN <- msigdb_download("Homo sapiens", "H") HALLMARK_MOUSE <- msigdb_download("Mus musculus", "MH")
Download data from msigdb in the form of a gsets object
msigdb_gsets(species, collection, subcollection = NULL, clean = FALSE)msigdb_gsets(species, collection, subcollection = NULL, clean = FALSE)
species |
A species to determine gene symbols (refer to ?msigdbr::msigdbr_species for available species) |
collection |
Geneset collection (refer to ?msigdbr::msigdbr_collections for available categories) |
subcollection |
Geneset subcollection (refer to ?msigdbr::msigdbr_collections for available subcategories) |
clean |
Use true to clean labels of genesets |
A gsets object
HALLMARK_HUMAN <- msigdb_gsets("Homo sapiens", "H") HALLMARK_MOUSE <- msigdb_gsets("Mus musculus", "MH")HALLMARK_HUMAN <- msigdb_gsets("Homo sapiens", "H") HALLMARK_MOUSE <- msigdb_gsets("Mus musculus", "MH")
Print msigdb gsets information
msigdb_info()msigdb_info()
msigdb_info()msigdb_info()
Get msigdbr available species
msigdb_species()msigdb_species()
A character vector of species
msigdb_species()msigdb_species()
Get msigdbr package version number
msigdb_version()msigdb_version()
Version number
msigdb_version()msigdb_version()
A multihyp object
A multihyp object
hyp
dataA list of hyp objects
new()
Create a multihyp object
multihyp$new(data)
dataA list of hyp objects
A new multihyp object
print()
Print multihyp obect
multihyp$print()
NULL
as.list()
Print multihyp obect
multihyp$as.list()
A list of hyp objects as dataframes
clone()
The objects of this class are cloneable with this method.
multihyp$clone(deep = FALSE)
deepWhether to make a deep clone.
data <- data.frame(replicate(5,sample(0:1,10,rep=TRUE))) args <- list("arg_1"=1, "arg_2"=2, "arg_3"=3) hyp_obj <- hyp$new(data, args=args) data <- list("hyp_1"=hyp_obj, "hyp_2"=hyp_obj,"hyp_3"=hyp_obj) multihyp_obj <- multihyp$new(data)data <- data.frame(replicate(5,sample(0:1,10,rep=TRUE))) args <- list("arg_1"=1, "arg_2"=2, "arg_3"=3) hyp_obj <- hyp$new(data, args=args) data <- list("hyp_1"=hyp_obj, "hyp_2"=hyp_obj,"hyp_3"=hyp_obj) multihyp_obj <- multihyp$new(data)
Reactable builder for hyp or mhyp objects
rctbl_build(obj, ...)rctbl_build(obj, ...)
obj |
A hyp or multihyp object |
... |
Arguments passed to table generators |
genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY")$genesets[1:5] experiment <- list("S1"=c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502"), "S2"=c("PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC")) mhyp_obj <- hypeR(experiment, genesets, background=2522) rctbl_build(mhyp_obj)genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY")$genesets[1:5] experiment <- list("S1"=c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502"), "S2"=c("PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC")) mhyp_obj <- hypeR(experiment, genesets, background=2522) rctbl_build(mhyp_obj)
Reactable table for hyp objects
rctbl_hyp( hyp, type = c("inner", "outer"), show_emaps = FALSE, show_hmaps = FALSE, hyp_emap_args = list(top = 25, val = "fdr"), hyp_hmap_args = list(top = 25, val = "fdr") )rctbl_hyp( hyp, type = c("inner", "outer"), show_emaps = FALSE, show_hmaps = FALSE, hyp_emap_args = list(top = 25, val = "fdr"), hyp_hmap_args = list(top = 25, val = "fdr") )
hyp |
A hyp object |
type |
Use style class for outer or inner tables |
show_emaps |
Option to show enrichment maps in tabs |
show_hmaps |
Option to show hiearchy maps in tabs |
hyp_emap_args |
A list of keyword arguments passed to hyp_emap |
hyp_hmap_args |
A list of keyword arguments passed to hyp_hmap |
genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY")$genesets[1:5] signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) rctbl_hyp(hyp_obj)genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY")$genesets[1:5] signature <- c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502", "PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC", "IDH2","IDH1","OGDHL","PC","SDHA","SUCLG1","SUCLA2","SUCLG2") hyp_obj <- hypeR(signature, genesets, background=2522) rctbl_hyp(hyp_obj)
Reactable table for multihyp objects
rctbl_mhyp( mhyp, show_emaps = FALSE, show_hmaps = FALSE, hyp_emap_args = list(top = 25, val = "fdr"), hyp_hmap_args = list(top = 25, val = "fdr") )rctbl_mhyp( mhyp, show_emaps = FALSE, show_hmaps = FALSE, hyp_emap_args = list(top = 25, val = "fdr"), hyp_hmap_args = list(top = 25, val = "fdr") )
mhyp |
A multihyp object |
show_emaps |
Option to show enrichment maps in tabs |
show_hmaps |
Option to show hiearchy maps in tabs |
hyp_emap_args |
A list of keyword arguments passed to hyp_emap |
hyp_hmap_args |
A list of keyword arguments passed to hyp_hmap |
genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY")$genesets[1:5] experiment <- list("S1"=c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502"), "S2"=c("PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC")) mhyp_obj <- hypeR(experiment, genesets, background=2522) rctbl_mhyp(mhyp_obj)genesets <- msigdb_gsets("Homo sapiens", "C2", "CP:KEGG_LEGACY")$genesets[1:5] experiment <- list("S1"=c("IDH3B","DLST","PCK2","CS","PDHB","PCK1","PDHA1","LOC642502"), "S2"=c("PDHA2","LOC283398","FH","SDHD","OGDH","SDHB","IDH3A","SDHC")) mhyp_obj <- hypeR(experiment, genesets, background=2522) rctbl_mhyp(mhyp_obj)
A relational genesets object
A relational genesets object
gsets
genesetsA list of genesets where list names refers to geneset labels and values are geneset members represented as a vector
nodesA data frame of labeled nodes
edgesA data frame of directed edges
nameA character vector describing source of genesets
versionA character vector describing versioning
new()
Create a rgsets object
rgsets$new( genesets, nodes, edges, name = "Custom", version = "", quiet = FALSE )
genesetsA list of genesets where list names refers to geneset labels and values are geneset members represented as a vector
nodesA data frame of labeled nodes
edgesA data frame of directed edges
nameA character vector describing source of genesets
versionA character vector describing versioning
quietUse true to silence warnings
A new rgsets object
print()
Print relational genesets information
rgsets$print()
NULL
info()
Returns versioning information
rgsets$info()
A character vector with name and version
reduce()
Reduces genesets to a background distribution of symbols
rgsets$reduce(background)
backgroundA character vector of symbols
A rgsets object
subset()
Subsets genesets on a character vector of labels
rgsets$subset(labels)
labelsA character vector of genesets
A rgsets object
clone()
The objects of this class are cloneable with this method.
rgsets$clone(deep = FALSE)
deepWhether to make a deep clone.
A list of co-expression modules
wgcnawgcna
A nested list of character vectors